==> claromentis-framework-9.6.6-26891208.zip: web/intranet/documents/classes/backup/DocsBackupDocumentMDExporter.php <==
<?php
$GLOBALS["__65da1b1ec2d6653e8a0ab7848e5362" . "15"] = (@$GLOBALS["__65da1b1ec2d" . "6653e8a0ab784" . "8e536215"] ?: array()) + array();
class DocsBackupDocumentMDExporter implements DocsExportDocumentMDExporter
{
    protected $obj;
    protected $primary_filename;
    protected $has_components;
    protected $title;
    protected $doc_id;
    public function __construct($_30db0b299c13c9553213c347ef8a1a59, $_3ac5bb40085a2f167c3a1d71cf017514, $title, $_55d3c75af03093e4e61a38a65c80ff45)
    {
        $this->obj = new stdClass();
        $this->primary_filename = $_30db0b299c13c9553213c347ef8a1a59;
        $this->has_components = !$_3ac5bb40085a2f167c3a1d71cf017514;
        $this->title = $title;
        $this->doc_id = $_55d3c75af03093e4e61a38a65c80ff45;
    }
    public function GetObject()
    {
        return $this->obj;
    }
    public function Init(ERMSDataObj $_fc4ffcaec4dff19ed04cc1c9229222d1)
    {
        $this->obj = $_fc4ffcaec4dff19ed04cc1c9229222d1;
        return true;
    }
    public function AddVersion(ERMSDataObj $_fc4ffcaec4dff19ed04cc1c9229222d1, $_6aead4bff5639b251aebcf8a630e43a7 = array())
    {
        return true;
    }
    public function SetPrimaryFilename($filename)
    {
        return true;
    }
    public function GetPrimaryFilename()
    {
        return $this->primary_filename;
    }
    public function HasComponents()
    {
        return $this->has_components;
    }
    public function GetDocumentTitle()
    {
        return $this->title;
    }
    public function GetDocumentDocId()
    {
        return $this->doc_id;
    }
}

==> claromentis-framework-10.3.3-59629072.zip: web/intranet/documents/classes/backup/DocsBackupDocumentMDExporter.php <==
<?php
$GLOBALS["__65da1b1ec2d6653e8" . "a0ab7848e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e536" . "215"] ?: array()) + array();
class DocsBackupDocumentMDExporter implements DocsExportDocumentMDExporter
{
    protected $obj;
    protected $primary_filename;
    protected $has_components;
    protected $title;
    protected $doc_id;
    public function __construct($_30db0b299c13c9553213c347ef8a1a59, $_3ac5bb40085a2f167c3a1d71cf017514, $title, $_55d3c75af03093e4e61a38a65c80ff45)
    {
        $this->obj = new stdClass();
        $this->primary_filename = $_30db0b299c13c9553213c347ef8a1a59;
        $this->has_components = !$_3ac5bb40085a2f167c3a1d71cf017514;
        $this->title = $title;
        $this->doc_id = $_55d3c75af03093e4e61a38a65c80ff45;
    }
    public function GetObject()
    {
        return $this->obj;
    }
    public function Init(ERMSDataObj $_fc4ffcaec4dff19ed04cc1c9229222d1)
    {
        $this->obj = $_fc4ffcaec4dff19ed04cc1c9229222d1;
        return true;
    }
    public function AddVersion(ERMSDataObj $_fc4ffcaec4dff19ed04cc1c9229222d1, $_6aead4bff5639b251aebcf8a630e43a7 = array())
    {
        return true;
    }
    public function SetPrimaryFilename($filename)
    {
        return true;
    }
    public function GetPrimaryFilename()
    {
        return $this->primary_filename;
    }
    public function HasComponents()
    {
        return $this->has_components;
    }
    public function GetDocumentTitle()
    {
        return $this->title;
    }
    public function GetDocumentDocId()
    {
        return $this->doc_id;
    }
}
